==> audiowiki_1.0.2-21.tar.gz: audiowiki-1.0.2/playlists.cpp <==
#include "playlists.h"
#include <QSettings>
#include <QFile>
#include <QDebug>
#include <QDesktopServices>

Playlists::Playlists()
{
    playlistFile = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "playlists.dat");
    if (playlistFile->open(QIODevice::ReadOnly))
    {
        QDataStream in(playlistFile);   // we will serialize the data into the file
        in >> this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"file error";


}

QStringList Playlists::getPlaylistContent(QString title)
{
    QStringList articles;
    articles = playlists.value(title);
    return articles;
}

QMap<QString, QStringList> Playlists::getPlaylists()
{
    return this->playlists;
}

QStringList Playlists::getPlaylistTitles()
{
    QStringList titles = playlists.keys();
    return titles;
}

void Playlists::addNewItemToPlaylist(QString title, QString item)
{
    QStringList items = this->playlists.take(title);
    items.append(item);
    this->playlists.insert(title, items);
    if (playlistFile->open(QIODevice::WriteOnly))
    {
        QDataStream out(playlistFile);   // we will serialize the data into the file
        out << this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"write error";

}

void Playlists::removePlaylistItem(QString item, int column, QTreeWidgetItem *parent)
{
    if (playlists.keys().contains(item))
    {
        playlists.remove(item);
        if (playlistFile->open(QIODevice::WriteOnly))
        {
            QDataStream out(playlistFile);   // we will serialize the data into the file
            out << this->playlists;
            playlistFile->close();
        }
        else
            qDebug()<<"write error";
    }
    else
    {
        QStringList items;
        items = playlists.take(parent->text(column));
        if (items.contains(item))
        {

            items.removeOne(item);

        }
        playlists.insert(parent->text(column), items);
        if (playlistFile->open(QIODevice::WriteOnly))
        {
            QDataStream out(playlistFile);   // we will serialize the data into the file
            out << this->playlists;
            playlistFile->close();
        }
        else
            qDebug()<<"write error";
    }

}

void Playlists::removePlaylist(QString title)
{
    playlists.remove(title);
    if (playlistFile->open(QIODevice::WriteOnly))
    {
        QDataStream out(playlistFile);   // we will serialize the data into the file
        out << this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"write error";

}

==> audiowiki_1.0.3-2.tar.gz: audiowiki-1.0.3/playlists.cpp <==
#include "playlists.h"
#include <QSettings>
#include <QFile>
#include <QDebug>
#include <QDesktopServices>

Playlists::Playlists()
{
    playlistFile = new QFile("/home/user/MyDocs/.audiowiki/playlists.dat");
    if (playlistFile->open(QIODevice::ReadOnly))
    {
        QDataStream in(playlistFile);   // we will serialize the data into the file
        in >> this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"file error";


}

QStringList Playlists::getPlaylistContent(QString title)
{
    QStringList articles;
    articles = playlists.value(title);
    return articles;
}

QMap<QString, QStringList> Playlists::getPlaylists()
{
    return this->playlists;
}

QStringList Playlists::getPlaylistTitles()
{
    QStringList titles = playlists.keys();
    return titles;
}

void Playlists::addNewItemToPlaylist(QString title, QString item)
{
    QStringList items = this->playlists.take(title);
    items.append(item);
    this->playlists.insert(title, items);
    if (playlistFile->open(QIODevice::WriteOnly))
    {
        QDataStream out(playlistFile);   // we will serialize the data into the file
        out << this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"write error";

}

void Playlists::removePlaylistItem(QString item, int column, QTreeWidgetItem *parent)
{
    if (playlists.keys().contains(item))
    {
        playlists.remove(item);
        if (playlistFile->open(QIODevice::WriteOnly))
        {
            QDataStream out(playlistFile);   // we will serialize the data into the file
            out << this->playlists;
            playlistFile->close();
        }
        else
            qDebug()<<"write error";
    }
    else
    {
        QStringList items;
        items = playlists.take(parent->text(column));
        if (items.contains(item))
        {

            items.removeOne(item);

        }
        playlists.insert(parent->text(column), items);
        if (playlistFile->open(QIODevice::WriteOnly))
        {
            QDataStream out(playlistFile);   // we will serialize the data into the file
            out << this->playlists;
            playlistFile->close();
        }
        else
            qDebug()<<"write error";
    }

}

void Playlists::removePlaylist(QString title)
{
    playlists.remove(title);
    if (playlistFile->open(QIODevice::WriteOnly))
    {
        QDataStream out(playlistFile);   // we will serialize the data into the file
        out << this->playlists;
        playlistFile->close();
    }
    else
        qDebug()<<"write error";

}
